@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # vim: set expandtab tabstop=4 shiftwidth=4:
 
-# Copyright (c) 2020 CJ Kucera (cj@apocalyptech.com)
+# Copyright (c) 2020-2021 CJ Kucera (cj@apocalyptech.com)
 # 
 # This software is provided 'as-is', without any express or implied warranty.
 # In no event will the authors be held liable for any damages arising from
@@ -1609,3 +1609,64 @@ class BL3Save(object):
                         league_instance=0,
                         ))
 
+    def delete_mission(self, pt, mission_obj, allow_plot=False):
+        """
+        Deletes the specified mission (with object path `mission_obj`), in the
+        playthrough `pt` (0 = Normal/NVHM, 1 = TVHM) from the savegame entirely.
+        By default, this method will refuse to delete plot missions, since doing
+        so will lock out the game progress, if no other edits are made.  Setting
+        `allow_plot` to `True` will permit that action.  Returns `True` if the
+        mission was deleted, or `False` if the specified mission wasn't found,
+        or wasn't permitted to be deleted on account of `allow_plot`.
+        """
+        lower = mission_obj.lower()
+        if not allow_plot and lower in plot_missions:
+            return False
+        if len(self.save.mission_playthroughs_data) <= pt:
+            return False
+        # Originally tried a fancier `itertools.filterfalse` assignment here, but
+        # repeated protobufs can't be assigned directly, and doing a del/extend
+        # dance seemed sillier than just doing it this "dumb" way.
+        to_del_idx = None
+        for idx, mission in enumerate(self.save.mission_playthroughs_data[pt].mission_list):
+            if mission.mission_class_path.lower() == lower:
+                to_del_idx = idx
+                break
+        if to_del_idx is None:
+            return False
+        else:
+            del self.save.mission_playthroughs_data[pt].mission_list[idx]
+            return True
+
+    def clear_challenge_prefix(self, prefix):
+        """
+        Removes all challenge data which matches the given `prefix`.  Completely
+        removes the entries, as opposed to trying to intelligently clear their
+        values.
+        """
+        prefix_lower = prefix.lower()
+        indicies_to_del = []
+        for idx, challenge in enumerate(self.save.challenge_data):
+            if challenge.challenge_class_path.lower().startswith(prefix_lower):
+                indicies_to_del.append(idx)
+        for idx in reversed(indicies_to_del):
+            del self.save.challenge_data[idx]
+
+    def clear_bloody_harvest(self):
+        """
+        Clears all Bloody Harvest challenge data
+        """
+        self.clear_challenge_prefix('/Game/PatchDLC/BloodyHarvest/')
+
+    def clear_broken_hearts(self):
+        """
+        Clears all Broken Hearts challenge data
+        """
+        self.clear_challenge_prefix('/Game/PatchDLC/EventVDay/')
+
+    def clear_cartels(self):
+        """
+        Clears all Revenge of the Cartels challenge data
+        """
+        self.clear_challenge_prefix('/Game/PatchDLC/Event2/')
+
