@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # vim: set expandtab tabstop=4 shiftwidth=4:
 
-# Copyright (c) 2020 CJ Kucera (cj@apocalyptech.com)
+# Copyright (c) 2020-2021 CJ Kucera (cj@apocalyptech.com)
 # 
 # This software is provided 'as-is', without any express or implied warranty.
 # In no event will the authors be held liable for any damages arising from
@@ -26,6 +26,7 @@ import sys
 import bl3save
 import argparse
 from . import cli_common
+from . import plot_missions
 from bl3save.bl3save import BL3Save
 
 def main():
@@ -203,6 +204,48 @@ def main():
             help='Allow importing Fabricator when importing items from file',
             )
 
+    parser.add_argument('--delete-pt1-mission',
+            type=str,
+            metavar='MISSIONPATH',
+            action='append',
+            help="""Deletes all stored info about the specified mission in
+                Playthrough 1 (Normal).  Will only work on sidemissions.
+                Use bl3-save-info's --mission-paths to see the correct
+                mission path to use here.  This option can be specified
+                more than once."""
+            )
+
+    parser.add_argument('--delete-pt2-mission',
+            type=str,
+            metavar='MISSIONPATH',
+            action='append',
+            help="""Deletes all stored info about the specified mission in
+                Playthrough 2 (TVHM).  Will only work on sidemissions.
+                Use bl3-save-info's --mission-paths to see the correct
+                mission path to use here.  This option can be specified
+                more than once."""
+            )
+
+    parser.add_argument('--clear-bloody-harvest',
+            action='store_true',
+            help='Clear Bloody Harvest challenge state',
+            )
+
+    parser.add_argument('--clear-broken-hearts',
+            action='store_true',
+            help='Clear Broken Hearts challenge state',
+            )
+
+    parser.add_argument('--clear-cartels',
+            action='store_true',
+            help='Clear Revenge of the Cartels challenge state',
+            )
+
+    parser.add_argument('--clear-all-events',
+            action='store_true',
+            help='Clear all seasonal event challenge states',
+            )
+
     # Positional args
     parser.add_argument('input_filename',
             help='Input filename',
@@ -260,6 +303,13 @@ def main():
                 bl3save.max_level,
                 ))
 
+    # Check to make sure that any deleted missions are not plot missions
+    for arg in [args.delete_pt1_mission, args.delete_pt2_mission]:
+        if arg is not None:
+            for mission in arg:
+                if mission.lower() in plot_missions:
+                    raise argparse.ArgumentTypeError('Plot mission cannot be deleted: {}'.format(mission))
+
     # Check for overwrite warnings
     if os.path.exists(args.output_filename) and not args.force:
         if args.output_filename == args.input_filename:
@@ -306,6 +356,12 @@ def main():
         args.item_levels,
         args.unfinish_nvhm,
         args.item_mayhem_levels is not None,
+        args.delete_pt1_mission is not None,
+        args.delete_pt2_mission is not None,
+        args.clear_bloody_harvest,
+        args.clear_broken_hearts,
+        args.clear_cartels,
+        args.clear_all_events,
         ])
 
     # Make changes
@@ -379,6 +435,38 @@ def main():
                 print(' - Clearing Takedown Discovery missions')
             save.clear_takedown_discovery()
 
+        # Deleting missions
+        for label, pt, arg in [
+                ('Normal/NVHM', 0, args.delete_pt1_mission),
+                ('TVHM', 1, args.delete_pt2_mission),
+                ]:
+            if arg is not None:
+                for mission in arg:
+                    if not args.quiet:
+                        print(' - Deleting {} mission: {}'.format(label, mission))
+                    if not save.delete_mission(pt, mission):
+                        if not args.quiet:
+                            print('   NOTE: Could not find {} mission to delete: {}'.format(
+                                label,
+                                mission,
+                                ))
+
+        # Clearing seasonal event status
+        if args.clear_bloody_harvest or args.clear_all_events:
+            if not args.quiet:
+                print(' - Clearing Bloody Harvest challenge state')
+            save.clear_bloody_harvest()
+
+        if args.clear_broken_hearts or args.clear_all_events:
+            if not args.quiet:
+                print(' - Clearing Broken Hearts challenge state')
+            save.clear_broken_hearts()
+
+        if args.clear_cartels or args.clear_all_events:
+            if not args.quiet:
+                print(' - Clearing Cartels challenge state')
+            save.clear_cartels()
+
         # Unlocks
         if len(args.unlock) > 0:
             if not args.quiet:
